@@ -1,6 +1,6 @@
 context("CASCORE")
 
-test_that("SCORE stops when it should", {
+test_that("CASCORE stops when it should", {
   expect_error( runningmean(0, c(0,0)) )
 })
 
@@ -41,6 +41,6 @@ for (i in 1: ncol(D0)){
 
 test_that("This function returns a list of predicted membership of all nodes, the optimal weight between the graph
           and the covariates, as well as within-group variances for each value of alpha", {
-  expect_length(CASCORE(Adj, X, K)$estall, n)
-  expect_length(unique(CASCORE(Adj, X, K)$estall), K)
+  expect_length(CASCORE(Adj, X, K), n)
+  expect_length(unique(CASCORE(Adj, X, K)), K)
 })
