@@ -1,11 +1,10 @@
-require(igraph)
-
 context("SCORE")
 
 test_that("SCORE stops when it should", {
   expect_error( runningmean(0, c(0,0)) )
 })
 
+library(igraph)
 # Simulate the Network
 n = 10; K = 2;
 theta = 0.4 + (0.45-0.05)*(seq(1:n)/n)^2; Theta = diag(theta);
